@@ -1,10 +1,9 @@
 from dataclasses import dataclass
-from typing import List, Literal, Optional
+from typing import List, Optional
 from uuid import UUID
 
 from pybotx.async_buffer import AsyncBufferWritable
 from pybotx.bot.contextvars import bot_var
-from pybotx.models.enums import AttachmentTypes
 
 
 @dataclass
@@ -24,8 +23,6 @@ class Sticker:
     image_link: str
     pack_id: UUID
 
-    type: Literal[AttachmentTypes.STICKER] = AttachmentTypes.STICKER
-
     async def download(
         self,
         async_buffer: AsyncBufferWritable,
